@@ -265,7 +265,7 @@ func wrappedMain() int {
 		Args:         args,
 		Autocomplete: true,
 		Commands:     Commands,
-		HelpFunc:     excludeHelpFunc(Commands, []string{"plugin"}),
+		HelpFunc:     excludeHelpFunc(Commands, []string{"execute", "plugin"}),
 		HelpWriter:   os.Stdout,
 		Name:         "packer",
 		Version:      version.Version,
@@ -329,14 +329,20 @@ func extractMachineReadable(args []string) ([]string, bool) {
 }
 
 func loadConfig() (*config, error) {
+	pluginDir, err := packer.PluginFolder()
+	if err != nil {
+		return nil, err
+	}
+
 	var config config
 	config.Plugins = &packer.PluginConfig{
-		PluginMinPort:      10000,
-		PluginMaxPort:      25000,
-		KnownPluginFolders: packer.PluginFolders("."),
-	}
-	if err := config.Plugins.Discover(); err != nil {
-		return nil, err
+		PluginMinPort:   10000,
+		PluginMaxPort:   25000,
+		PluginDirectory: pluginDir,
+		Builders:        packer.MapOfBuilder{},
+		Provisioners:    packer.MapOfProvisioner{},
+		PostProcessors:  packer.MapOfPostProcessor{},
+		DataSources:     packer.MapOfDatasource{},
 	}
 
 	// Finally, try to use an internal plugin. Note that this will not override
@@ -375,7 +381,9 @@ func loadConfig() (*config, error) {
 		return nil, err
 	}
 
-	config.LoadExternalComponentsFromConfig()
+	if err := config.LoadExternalComponentsFromConfig(); err != nil {
+		return nil, fmt.Errorf("%s: %s", configFilePath, err)
+	}
 
 	return &config, nil
 }
