@@ -13,12 +13,12 @@ import (
 	"log"
 	"os"
 	"path/filepath"
+	"runtime"
 	"strings"
 	"testing"
 
 	"github.com/google/go-cmp/cmp"
 	"github.com/hashicorp/go-version"
-	"github.com/hashicorp/hcl/v2"
 	"github.com/hashicorp/packer/hcl2template/addrs"
 )
 
@@ -36,9 +36,7 @@ func TestChecksumFileEntry_init(t *testing.T) {
 	expectedVersion := "v0.3.0"
 	req := &Requirement{
 		Identifier: &addrs.Plugin{
-			Hostname:  "github.com",
-			Namespace: "ddelnano",
-			Type:      "xenserver",
+			Source: "github.com/ddelnano/xenserver",
 		},
 	}
 
@@ -58,311 +56,6 @@ func TestChecksumFileEntry_init(t *testing.T) {
 	}
 }
 
-func TestPlugin_ListInstallations(t *testing.T) {
-
-	type fields struct {
-		Identifier         string
-		VersionConstraints version.Constraints
-	}
-	tests := []struct {
-		name    string
-		fields  fields
-		opts    ListInstallationsOptions
-		wantErr bool
-		want    InstallList
-	}{
-
-		{
-			"windows_all_plugins",
-			fields{
-				// empty
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
-				BinaryInstallationOptions{
-					OS: "windows", ARCH: "amd64",
-					Ext: ".exe",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v1.2.3",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.3_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v1.2.4",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.4_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.5_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.6",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.6_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.7",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.7_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.8",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.8_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.6",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.6_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.9",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.9_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.6",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp copy", "google", "packer-plugin-google_v4.5.6_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.9",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp copy", "google", "packer-plugin-google_v4.5.9_x5.0_windows_amd64.exe"),
-				},
-			},
-		},
-
-		{
-			"darwin_amazon_prot_5.0",
-			fields{
-				Identifier: "github.com/hashicorp/amazon",
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
-				BinaryInstallationOptions{
-					APIVersionMajor: "5", APIVersionMinor: "0",
-					OS: "darwin", ARCH: "amd64",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v1.2.3",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.3_x5.0_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.4",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.4_x5.0_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.5_x5.0_darwin_amd64"),
-				},
-			},
-		},
-		{
-			"darwin_amazon_prot_5.1",
-			fields{
-				Identifier: "github.com/hashicorp/amazon",
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
-				BinaryInstallationOptions{
-					APIVersionMajor: "5", APIVersionMinor: "1",
-					OS: "darwin", ARCH: "amd64",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v1.2.3",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.3_x5.0_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.3",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.3_x5.1_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.4",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.4_x5.0_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.5_x5.0_darwin_amd64"),
-				},
-				{
-					Version:    "v1.2.6",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.6_x5.1_darwin_amd64"),
-				},
-			},
-		},
-		{
-			"windows_amazon",
-			fields{
-				Identifier: "github.com/hashicorp/amazon",
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
-				BinaryInstallationOptions{
-					APIVersionMajor: "5", APIVersionMinor: "0",
-					OS: "windows", ARCH: "amd64",
-					Ext: ".exe",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v1.2.3",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.3_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v1.2.4",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.4_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.5_x5.0_windows_amd64.exe"),
-				},
-			},
-		},
-		{
-			"windows_google_multifolder",
-			fields{
-				Identifier: "github.com/hashicorp/google",
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
-				BinaryInstallationOptions{
-					APIVersionMajor: "5", APIVersionMinor: "0",
-					OS: "windows", ARCH: "amd64",
-					Ext: ".exe",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v4.5.6",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.6_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.7",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.7_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.8",
-					BinaryPath: filepath.Join(pluginFolderOne, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.8_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.6",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.6_x5.0_windows_amd64.exe"),
-				},
-				{
-					Version:    "v4.5.9",
-					BinaryPath: filepath.Join(pluginFolderTwo, "github.com", "hashicorp", "google", "packer-plugin-google_v4.5.9_x5.0_windows_amd64.exe"),
-				},
-			},
-		},
-		{
-			"test nil identifier - multiple plugins with same version",
-			fields{
-				Identifier: "",
-			},
-			ListInstallationsOptions{
-				[]string{
-					pluginFolderThree,
-				},
-				BinaryInstallationOptions{
-					APIVersionMajor: "5", APIVersionMinor: "0",
-					OS: "linux", ARCH: "amd64",
-					Checksummers: []Checksummer{
-						{
-							Type: "sha256",
-							Hash: sha256.New(),
-						},
-					},
-				},
-			},
-			false,
-			[]*Installation{
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderThree, "github.com", "hashicorp", "alazon", "packer-plugin-alazon_v1.2.5_x5.0_linux_amd64"),
-				},
-				{
-					Version:    "v1.2.5",
-					BinaryPath: filepath.Join(pluginFolderThree, "github.com", "hashicorp", "amazon", "packer-plugin-amazon_v1.2.5_x5.0_linux_amd64"),
-				},
-			},
-		},
-	}
-	for _, tt := range tests {
-		t.Run(tt.name, func(t *testing.T) {
-			var identifier *addrs.Plugin
-			if tt.fields.Identifier != "" {
-				var diags hcl.Diagnostics
-				identifier, diags = addrs.ParsePluginSourceString(tt.fields.Identifier)
-				if diags.HasErrors() {
-					t.Fatalf("%v", diags)
-				}
-			}
-			p := Requirement{
-				Identifier:         identifier,
-				VersionConstraints: tt.fields.VersionConstraints,
-			}
-			got, err := p.ListInstallations(tt.opts)
-			if (err != nil) != tt.wantErr {
-				t.Errorf("Plugin.ListInstallations() error = %v, wantErr %v", err, tt.wantErr)
-				return
-			}
-			if diff := cmp.Diff(tt.want, got); diff != "" {
-				t.Errorf("Plugin.ListInstallations() unexpected output: %s", diff)
-			}
-		})
-	}
-}
-
 func TestRequirement_InstallLatest(t *testing.T) {
 	type fields struct {
 		Identifier         string
@@ -398,11 +91,7 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderOne,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "5", APIVersionMinor: "0",
@@ -435,11 +124,7 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderOne,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "5", APIVersionMinor: "1",
@@ -481,11 +166,7 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderOne,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "5", APIVersionMinor: "0",
@@ -519,21 +200,22 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						ChecksumFileEntries: map[string][]ChecksumFileEntry{
 							"2.10.0": {{
 								Filename: "packer-plugin-amazon_v2.10.0_x6.0_darwin_amd64.zip",
-								Checksum: "43156b1900dc09b026b54610c4a152edd277366a7f71ff3812583e4a35dd0d4a",
+								Checksum: "5763f8b5b5ed248894e8511a089cf399b96c7ef92d784fb30ee6242a7cb35bce",
 							}},
 						},
 						Zips: map[string]io.ReadCloser{
 							"github.com/hashicorp/packer-plugin-amazon/packer-plugin-amazon_v2.10.0_x6.0_darwin_amd64.zip": zipFile(map[string]string{
-								"packer-plugin-amazon_v2.10.0_x6.0_darwin_amd64": "v2.10.0_x6.0_darwin_amd64",
+								// Make the false plugin echo an output that matches a subset of `describe` for install to work
+								//
+								// Note: this won't work on Windows as they don't have bin/sh, but this will
+								// eventually be replaced by acceptance tests.
+								"packer-plugin-amazon_v2.10.0_x6.0_darwin_amd64": `#!/bin/sh
+echo '{"version":"v2.10.0","api_version":"x6.0"}'`,
 							}),
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderTwo,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "6", APIVersionMinor: "1",
@@ -570,21 +252,22 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						ChecksumFileEntries: map[string][]ChecksumFileEntry{
 							"2.10.1": {{
 								Filename: "packer-plugin-amazon_v2.10.1_x6.1_darwin_amd64.zip",
-								Checksum: "90ca5b0f13a90238b62581bbf30bacd7e2c9af6592c7f4849627bddbcb039dec",
+								Checksum: "51451da5cd7f1ecd8699668d806bafe58a9222430842afbefdc62a6698dab260",
 							}},
 						},
 						Zips: map[string]io.ReadCloser{
 							"github.com/hashicorp/packer-plugin-amazon/packer-plugin-amazon_v2.10.1_x6.1_darwin_amd64.zip": zipFile(map[string]string{
-								"packer-plugin-amazon_v2.10.1_x6.1_darwin_amd64": "v2.10.1_x6.1_darwin_amd64",
+								// Make the false plugin echo an output that matches a subset of `describe` for install to work
+								//
+								// Note: this won't work on Windows as they don't have bin/sh, but this will
+								// eventually be replaced by acceptance tests.
+								"packer-plugin-amazon_v2.10.1_x6.1_darwin_amd64": `#!/bin/sh
+echo '{"version":"v2.10.1","api_version":"x6.1"}'`,
 							}),
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderTwo,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "6", APIVersionMinor: "1",
@@ -621,21 +304,22 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						ChecksumFileEntries: map[string][]ChecksumFileEntry{
 							"2.10.0": {{
 								Filename: "packer-plugin-amazon_v2.10.0_x6.1_linux_amd64.zip",
-								Checksum: "825fc931ae0cb151df0c56be41a17a9136c4d1f1ee73ddb8ed6baa17cef31afa",
+								Checksum: "5196f57f37e18bfeac10168db6915caae0341bfc4168ebc3d2b959d746cebd0a",
 							}},
 						},
 						Zips: map[string]io.ReadCloser{
 							"github.com/hashicorp/packer-plugin-amazon/packer-plugin-amazon_v2.10.0_x6.1_linux_amd64.zip": zipFile(map[string]string{
-								"packer-plugin-amazon_v2.10.0_x6.1_linux_amd64": "v2.10.0_x6.1_linux_amd64",
+								// Make the false plugin echo an output that matches a subset of `describe` for install to work
+								//
+								// Note: this won't work on Windows as they don't have bin/sh, but this will
+								// eventually be replaced by acceptance tests.
+								"packer-plugin-amazon_v2.10.0_x6.1_linux_amd64": `#!/bin/sh
+echo '{"version":"v2.10.0","api_version":"x6.1"}'`,
 							}),
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderTwo,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "6", APIVersionMinor: "1",
@@ -676,11 +360,7 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-					pluginFolderOne,
-					pluginFolderTwo,
-				},
+				pluginFolderTwo,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "6", APIVersionMinor: "1",
@@ -720,9 +400,7 @@ func TestRequirement_InstallLatest(t *testing.T) {
 						},
 					},
 				},
-				[]string{
-					pluginFolderWrongChecksums,
-				},
+				pluginFolderTwo,
 				false,
 				BinaryInstallationOptions{
 					APIVersionMajor: "6", APIVersionMinor: "1",
@@ -740,11 +418,21 @@ func TestRequirement_InstallLatest(t *testing.T) {
 	}
 	for _, tt := range tests {
 		t.Run(tt.name, func(t *testing.T) {
+			switch tt.name {
+			case "upgrade-with-diff-protocol-version",
+				"upgrade-with-same-protocol-version",
+				"upgrade-with-one-missing-checksum-file":
+				if runtime.GOOS != "windows" {
+					break
+				}
+				t.Skipf("Test %q cannot run on Windows because of a shell script being invoked, skipping.", tt.name)
+			}
+
 			log.Printf("starting %s test", tt.name)
 
-			identifier, diags := addrs.ParsePluginSourceString("github.com/hashicorp/" + tt.fields.Identifier)
-			if len(diags) != 0 {
-				t.Fatalf("ParsePluginSourceString(%q): %v", tt.fields.Identifier, diags)
+			identifier, err := addrs.ParsePluginSourceString("github.com/hashicorp/" + tt.fields.Identifier)
+			if err != nil {
+				t.Fatalf("ParsePluginSourceString(%q): %v", tt.fields.Identifier, err)
 			}
 			cts, err := version.NewConstraint(tt.fields.VersionConstraints)
 			if err != nil {
@@ -796,9 +484,10 @@ func (g *mockPluginGetter) Get(what string, options GetOptions) (io.ReadCloser,
 		}
 		toEncode = enc
 	case "zip":
-		acc := options.PluginRequirement.Identifier.Hostname + "/" +
-			options.PluginRequirement.Identifier.RealRelativePath() + "/" +
-			options.ExpectedZipFilename()
+		// Note: we'll act as if the plugin sources would always be github sources for now.
+		// This test will need to be updated if/when we move on to support other sources.
+		parts := options.PluginRequirement.Identifier.Parts()
+		acc := fmt.Sprintf("%s/%s/packer-plugin-%s/%s", parts[0], parts[1], parts[2], options.ExpectedZipFilename())
 
 		zip, found := g.Zips[acc]
 		if found == false {
@@ -843,3 +532,235 @@ func zipFile(content map[string]string) io.ReadCloser {
 }
 
 var _ Getter = &mockPluginGetter{}
+
+func Test_LessInstallList(t *testing.T) {
+	tests := []struct {
+		name       string
+		installs   InstallList
+		expectLess bool
+	}{
+		{
+			"v1.2.1 < v1.2.2 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.1",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2",
+					APIVersion: "x5.0",
+				},
+			},
+			true,
+		},
+		{
+			// Impractical with the changes to the loading model
+			"v1.2.1 = v1.2.1 => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.1",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.1",
+					APIVersion: "x5.0",
+				},
+			},
+			false,
+		},
+		{
+			"v1.2.2 < v1.2.1 => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.1",
+					APIVersion: "x5.0",
+				},
+			},
+			false,
+		},
+		{
+			"v1.2.2-dev < v1.2.2 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2-dev",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2",
+					APIVersion: "x5.0",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.2 < v1.2.2-dev => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2-dev",
+					APIVersion: "x5.0",
+				},
+			},
+			false,
+		},
+		{
+			"v1.2.1 < v1.2.2-dev => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.1",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2-dev",
+					APIVersion: "x5.0",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.3 < v1.2.2-dev => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.2-dev",
+					APIVersion: "x5.0",
+				},
+			},
+			false,
+		},
+		{
+			"v1.2.3_x5.0 < v1.2.3_x5.1 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.1",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.3_x5.0 < v1.2.3_x5.0 => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+			},
+			false,
+		},
+		{
+			"v1.2.3_x4.15 < v1.2.3_x5.0 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x4.15",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.3_x9.0 < v1.2.3_x10.0 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x9.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x10.0",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.3_x5.9 < v1.2.3_x5.10 => true",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.9",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.10",
+				},
+			},
+			true,
+		},
+		{
+			"v1.2.3_x5.0 < v1.2.3_x4.15 => false",
+			InstallList{
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x5.0",
+				},
+				&Installation{
+					BinaryPath: "host/org/plugin",
+					Version:    "v1.2.3",
+					APIVersion: "x4.15",
+				},
+			},
+			false,
+		},
+	}
+
+	for _, tt := range tests {
+		t.Run(tt.name, func(t *testing.T) {
+			isLess := tt.installs.Less(0, 1)
+			if isLess != tt.expectLess {
+				t.Errorf("Less mismatch for %s_%s < %s_%s, expected %t, got %t",
+					tt.installs[0].Version,
+					tt.installs[0].APIVersion,
+					tt.installs[1].Version,
+					tt.installs[1].APIVersion,
+					tt.expectLess, isLess)
+			}
+		})
+	}
+}
